#ifndef __rsngmo_HEADER
#define __rsngmo_HEADER


#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_WARN_NSUP_ID_QUERY     (          0x3FFC0101L)
#define VI_WARN_NSUP_RESET        (          0x3FFC0102L)
#define VI_WARN_NSUP_SELF_TEST    (          0x3FFC0103L)
#define VI_WARN_NSUP_ERROR_QUERY  (          0x3FFC0104L)
#define VI_WARN_NSUP_REV_QUERY    (          0x3FFC0105L)

#define VI_ERROR_PARAMETER1       (_VI_ERROR+0x3FFC0001L)
#define VI_ERROR_PARAMETER2       (_VI_ERROR+0x3FFC0002L)
#define VI_ERROR_PARAMETER3       (_VI_ERROR+0x3FFC0003L)
#define VI_ERROR_PARAMETER4       (_VI_ERROR+0x3FFC0004L)
#define VI_ERROR_PARAMETER5       (_VI_ERROR+0x3FFC0005L)
#define VI_ERROR_PARAMETER6       (_VI_ERROR+0x3FFC0006L)
#define VI_ERROR_PARAMETER7       (_VI_ERROR+0x3FFC0007L)
#define VI_ERROR_PARAMETER8       (_VI_ERROR+0x3FFC0008L)
#define VI_ERROR_FAIL_ID_QUERY    (_VI_ERROR+0x3FFC0011L)
#define VI_ERROR_INV_RESPONSE     (_VI_ERROR+0x3FFC0012L)

#define VI_ERROR_INSTR_FILE_OPEN                    (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE                   (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE        (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER8                   (_VI_ERROR+0x3FFC0808L)
#define VI_ERROR_INSTR_PARAMETER9                   (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10                  (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11                  (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12                  (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13                  (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14                  (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15                  (_VI_ERROR+0x3FFC080FL)

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
#define VI_WARNING_INSTR_OFFSET                          (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                       (_VI_ERROR+0x3FFC0900L)
/****************************************************************************************/
/*= Instrument Specific constants to make the user code clearer ========================*/
/****************************************************************************************/

/* Channels types */
#define RSNGMO_CHANNEL_A			0					/* Channel A */
#define RSNGMO_CHANNEL_B			1					/* Channel B */
#define RSNGMO_CHANNEL_BOTH			2					/* Both channels */
#define RSNGMO_DVMA					2					/* DVM A */
#define RSNGMO_DVMB					3					/* DVM B */

/* State */
#define RSNGMO_OFF					0					/* State OFF */
#define RSNGMO_ON					1					/* State ON */

/* Format Types */
#define RSNGMO_FORMAT_ASCII			0					/* Ascii Data Format */
#define RSNGMO_FORMAT_LONG			1					/* Long Data Format */
#define RSNGMO_FORMAT_SREAL			2					/* Simple Real Data Format */
#define RSNGMO_FORMAT_DREAL			3					/* Double Real Data Format */

/* Byte Order Types */
#define RSNGMO_BYTE_ORDER_NORM		0					/* Normal Byte Order */
#define RSNGMO_BYTE_ORDER_SWAP		1					/* Swapped Byte Order */

/* Output Bandwidth */
#define RSNGMO_OUTP_BAND_HIGH		0					/* Bandwidth High */
#define RSNGMO_OUTP_BAND_LOW		1					/* Bandwidth Low */

/* Source Current Limit Type */
#define RSNGMO_SOUR_CURR_TYPE_LIMIT	0					/* Current Limit Type LIMIT */
#define RSNGMO_SOUR_CURR_TYPE_TRIP	1					/* Current Limit Type TRIP */

/* Function Type */
#define RSNGMO_FUNC_AVERAGE			0					/* Average And Sample Measurement */
#define RSNGMO_FUNC_PEAK			1					/* Peak And Sample Measurement */
#define RSNGMO_FUNC_MIN				2					/* Min And Sample Measurement */
#define RSNGMO_FUNC_HIGH			3					/* High And Sample Measurement */
#define RSNGMO_FUNC_LOW				4					/* Low And Sample Measurement */
#define RSNGMO_FUNC_RMS				5					/* RMS And Sample Measurement */
#define RSNGMO_FUNC_VOLTAGE			6					/* Static voltage measurement */
#define RSNGMO_FUNC_CURRENT			7					/* Static current measurement */
#define RSNGMO_FUNC_DVM				8					/* Static DVM measurement */

/* Current Measurement Range */
#define RSNGMO_CURR_RANG_HIGH		0					/* Expected Current Meas. Range 5A */
#define RSNGMO_CURR_RANG_MEDIUM		1					/* Expected Current Meas. Range 0.5A */
#define RSNGMO_CURR_RANG_LOW		2					/* Expected Current Meas. Range 5mA */
#define RSNGMO_CURR_RANG_AUTO		3					/* Auto Ranging */

/* Pulse Channel */
#define RSNGMO_PULSE_CHAN_CURR		0					/* Current Measurement */
#define RSNGMO_PULSE_CHAN_DVM		1					/* DVM Measurement */

/* Trigger Range */
#define RSNGMO_TRIG_RANG_HIGH		0					/* Trigger Range High - 5A */
#define RSNGMO_TRIG_RANG_LOW		1					/* Trigger Range Low - 0.5A */
#define RSNGMO_TRIG_RANG_DVM		2					/* Trigger Range DVM */

/* Trigger Source */
#define RSNGMO_TRIG_SOURCE_INT		0					/* Trigger source intern */
#define RSNGMO_TRIG_SOURCE_EXT		1					/* Trigger source extern */

/* Trigger Slope */
#define RSNGMO_TRIG_SLOPE_POS		0					/* Trigger slope positive */
#define RSNGMO_TRIG_SLOPE_NEG		1					/* Trigger slope negative */

/* Registers */
#define RSNGMO_REG_SRE				0
#define RSNGMO_REG_ESE				1
#define RSNGMO_REG_QUES_ENAB		2
#define RSNGMO_REG_MEAS_ENAB		3
#define RSNGMO_REG_OPER_ENAB		4
#define RSNGMO_REG_STB				5
#define RSNGMO_REG_ESE_EVENT		6
#define RSNGMO_REG_QUES_COND		7
#define RSNGMO_REG_MEAS_COND		8
#define RSNGMO_REG_OPER_COND		9
#define RSNGMO_REG_QUES_EVENT		10	
#define RSNGMO_REG_MEAS_EVENT		11
#define RSNGMO_REG_OPER_EVENT		12

/* Serial Configuration */
#define RSNGMO_SER_DEL_CR		    0					 /* Serial Intreface Delimiter CR */
#define RSNGMO_SER_DEL_LF		    1					 /* Serial Interface Delimiter LF */

/* Trigger State */
#define RSNGMO_NOT_TRIGGED			0					 /* Voltage Protection State - Not Trigged */
#define RSNGMO_TRIGGED				1					 /* Voltage Protection State - Trigged */

/* Limit State */
#define RSNGMO_NOT_IN_LIMIT			0					/* Not In Current Limit/Not Tripped */
#define RSNGMO_IN_LIMIT				1					/* In Current Limit/Tripped */

/* Pulse Trigger State */
#define RSNGMO_PULSE_TRIGGER_NONE    0					/* None Pulse Trigger */
#define RSNGMO_PULSE_TRIGGER_TRIGG   1					/* Triggered Pulse Trigger */
#define RSNGMO_PULSE_TRIGGER_READY   2					/* Ready Pulse Trigger */
#define RSNGMO_PULSE_TRIGGER_TIMEOUT 3 					/* Timeout Pulse Trigger */

/* Serial Interface Parity */
#define RSNGMO_SER_PAR_NONE			0					/* None Parity */
#define RSNGMO_SER_PAR_ODD			1					/* Odd Parity */
#define RSNGMO_SER_PAR_EVEN			2					/* Even Parity */

/* Serial Interface Handshake */
#define RSNGMO_SER_HAND_NONE		0					/* None Handshake */
#define RSNGMO_SER_HAND_XON			1					/* XON/XOF Handshake */
#define RSNGMO_SER_HAND_HW			2					/* Hardware Handshake */


/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE	(_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER9				(_VI_ERROR+0x3FFC0809L)    

/****************************************************************************************/
/*= Instrument Specific Error/Warning Codes Here =======================================*/
/****************************************************************************************/
#define VI_INSTR_WARNING_OFFSET					(0x3FFC0900L)
#define VI_INSTR_ERROR_OFFSET					(_VI_ERROR+0x3FFC0900L)

#define RSNGMO_ERROR_INSTRUMENT_ERROR			(VI_INSTR_ERROR_OFFSET + 0xF0L)
#define RSNGMO_ERROR_MEASUREMENT_TIMEOUT        (VI_INSTR_ERROR_OFFSET + 0xF1L)
#define RSNGMO_ERROR_TRIGGER_TIMEOUT            (VI_INSTR_ERROR_OFFSET + 0xF2L)
#define RSNGMO_ERROR_FUNCTION_UNAVAILABLE		(VI_INSTR_ERROR_OFFSET + 0xF3L)

/****************************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) ==================*/
/****************************************************************************************/
ViStatus _VI_FUNC rsngmo_init (ViRsrc resourceName, ViBoolean IDQuery,
                               ViBoolean resetDevice, ViPSession instrumentHandle);
ViStatus _VI_FUNC rsngmo_configureFrontPanel (ViSession instrumentHandle,
                                              ViBoolean state,
                                              ViInt32 displayedChannel);
ViStatus _VI_FUNC rsngmo_setActiveDisplayChannel (ViSession instrumentHandle,
                                                  ViInt32 channel);
ViStatus _VI_FUNC rsngmo_getActiveDisplayChannel (ViSession instrumentHandle,
                                                  ViPInt32 channel);
ViStatus _VI_FUNC rsngmo_setDisplayState (ViSession instrumentHandle,
                                          ViBoolean state);
ViStatus _VI_FUNC rsngmo_getDisplayState (ViSession instrumentHandle,
                                          ViPBoolean state);
ViStatus _VI_FUNC rsngmo_setCommonOutputState (ViSession instrumentHandle,
                                               ViBoolean state);
ViStatus _VI_FUNC rsngmo_getCommonOutputState (ViSession instrumentHandle,
                                               ViPBoolean state);
ViStatus _VI_FUNC rsngmo_setBeeperState (ViSession instrumentHandle,
                                         ViInt32 channel, ViBoolean state);
ViStatus _VI_FUNC rsngmo_getBeeperState (ViSession instrumentHandle,
                                         ViInt32 channel, ViPBoolean state);
ViStatus _VI_FUNC rsngmo_setPowerOnSetup (ViSession instrumentHandle,
                                          ViInt32 setupNumber);
ViStatus _VI_FUNC rsngmo_getPowerOnSetup (ViSession instrumentHandle,
                                          ViPInt32 setupNumber);
ViStatus _VI_FUNC rsngmo_configureSerialSetup (ViSession instrumentHandle,
                                               ViBoolean serialPort,
                                               ViInt32 datalength, ViInt32 baudrate,
                                               ViInt32 parity, ViInt32 stopbits,
                                               ViInt32 handshake);
ViStatus _VI_FUNC rsngmo_setSerialState (ViSession instrumentHandle,
                                         ViBoolean state);
ViStatus _VI_FUNC rsngmo_getSerialState (ViSession instrumentHandle,
                                         ViPBoolean state);
ViStatus _VI_FUNC rsngmo_setBaudRate (ViSession instrumentHandle, ViInt32 baudRate);
ViStatus _VI_FUNC rsngmo_getBaudRate (ViSession instrumentHandle,
                                      ViPInt32 baudRate);
ViStatus _VI_FUNC rsngmo_setDatalength (ViSession instrumentHandle,
                                        ViInt32 dataLength);
ViStatus _VI_FUNC rsngmo_getDatalength (ViSession instrumentHandle,
                                        ViPInt32 dataLength);
ViStatus _VI_FUNC rsngmo_setParity (ViSession instrumentHandle, ViInt32 parity);
ViStatus _VI_FUNC rsngmo_getParity (ViSession instrumentHandle, ViPInt32 parity);
ViStatus _VI_FUNC rsngmo_setStopBits (ViSession instrumentHandle, ViInt32 stopBits);
ViStatus _VI_FUNC rsngmo_getStopBits (ViSession instrumentHandle,
                                      ViPInt32 stopBits);
ViStatus _VI_FUNC rsngmo_setHandshake (ViSession instrumentHandle,
                                       ViInt32 handshake);
ViStatus _VI_FUNC rsngmo_getHandshake (ViSession instrumentHandle,
                                       ViPInt32 handshake);
ViStatus _VI_FUNC rsngmo_setGPIBAddress (ViSession instrumentHandle,
                                         ViInt32 address);
ViStatus _VI_FUNC rsngmo_getGPIBAddress (ViSession instrumentHandle,
                                         ViPInt32 address);
ViStatus _VI_FUNC rsngmo_configureOutput (ViSession instrumentHandle,
                                          ViInt32 channel, ViBoolean state,
                                          ViInt32 bandwidth, ViReal64 impedance);
ViStatus _VI_FUNC rsngmo_setOutputState (ViSession instrumentHandle,
                                         ViInt32 channel, ViBoolean state);
ViStatus _VI_FUNC rsngmo_getOutputState (ViSession instrumentHandle,
                                         ViInt32 channel, ViPBoolean state);
ViStatus _VI_FUNC rsngmo_setOutputBandwidth (ViSession instrumentHandle,
                                             ViInt32 channel, ViInt32 bandwidth);
ViStatus _VI_FUNC rsngmo_getOutputBandwidth (ViSession instrumentHandle,
                                             ViInt32 channel, ViPInt32 bandwidth);
ViStatus _VI_FUNC rsngmo_setOutputImpedance (ViSession instrumentHandle,
                                             ViInt32 channel, ViReal64 impedance);
ViStatus _VI_FUNC rsngmo_getOutputImpedance (ViSession instrumentHandle,
                                             ViInt32 channel, ViPReal64 impedance);
ViStatus _VI_FUNC rsngmo_setOutputRelayState (ViSession instrumentHandle,
                                              ViInt32 relay, ViBoolean state);
ViStatus _VI_FUNC rsngmo_getOutputRelayState (ViSession instrumentHandle,
                                              ViInt32 relay, ViPBoolean state);
ViStatus _VI_FUNC rsngmo_configureSource (ViSession instrumentHandle,
                                          ViInt32 channel, ViReal64 voltageLevel,
                                          ViReal64 currentLimit,
                                          ViInt32 currentLimitType);
ViStatus _VI_FUNC rsngmo_configureSourceProtection (ViSession instrumentHandle,
                                                    ViInt32 channel,
                                                    ViReal64 voltageProtection,
                                                    ViReal64 maximumVoltage,
                                                    ViReal64 maximumCurrentLimit);
ViStatus _VI_FUNC rsngmo_setVoltage (ViSession instrumentHandle, ViInt32 channel,
                                     ViReal64 voltageLevel);
ViStatus _VI_FUNC rsngmo_getVoltage (ViSession instrumentHandle, ViInt32 channel,
                                     ViPReal64 voltageLevel);
ViStatus _VI_FUNC rsngmo_setVoltageProtection (ViSession instrumentHandle,
                                               ViInt32 channel,
                                               ViReal64 protectionLevel);
ViStatus _VI_FUNC rsngmo_getVoltageProtection (ViSession instrumentHandle,
                                               ViInt32 channel,
                                               ViPReal64 protectionLevel);
ViStatus _VI_FUNC rsngmo_getVoltageProtectionState (ViSession instrumentHandle,
                                                    ViInt32 channel,
                                                    ViPInt32 state);
ViStatus _VI_FUNC rsngmo_setVoltageMaxSetting (ViSession instrumentHandle,
                                               ViInt32 channel, ViReal64 max);
ViStatus _VI_FUNC rsngmo_getVoltageMaxSetting (ViSession instrumentHandle,
                                               ViInt32 channel, ViPReal64 max);
ViStatus _VI_FUNC rsngmo_setCurrentLimit (ViSession instrumentHandle,
                                          ViInt32 channel, ViReal64 limit);
ViStatus _VI_FUNC rsngmo_getCurrentLimit (ViSession instrumentHandle,
                                          ViInt32 channel, ViPReal64 limit);
ViStatus _VI_FUNC rsngmo_setCurrentLimitMaxSetting (ViSession instrumentHandle,
                                                    ViInt32 channel, ViReal64 max);
ViStatus _VI_FUNC rsngmo_getCurrentLimitMaxSetting (ViSession instrumentHandle,
                                                    ViInt32 channel, ViPReal64 max);
ViStatus _VI_FUNC rsngmo_setCurrentLimitType (ViSession instrumentHandle,
                                              ViInt32 channel, ViInt32 type);
ViStatus _VI_FUNC rsngmo_getCurrentLimitType (ViSession instrumentHandle,
                                              ViInt32 channel, ViPInt32 type);
ViStatus _VI_FUNC rsngmo_getCurrentLimitState (ViSession instrumentHandle,
                                               ViInt32 channel, ViPInt32 state);
ViStatus _VI_FUNC rsngmo_armTrigger (ViSession instrumentHandle, ViInt32 channel);
ViStatus _VI_FUNC rsngmo_trigger (ViSession instrumentHandle, ViInt32 channel);
ViStatus _VI_FUNC rsngmo_configureMeasurement (ViSession instrumentHandle,
                                               ViInt32 channel, ViInt32 function,
                                               ViInt32 currentRange,
                                               ViInt32 averageCount,
                                               ViReal64 interval);
ViStatus _VI_FUNC rsngmo_configurePulseMeasurement (ViSession instrumentHandle,
                                                    ViInt32 channel,
                                                    ViInt32 pulseChannel,
                                                    ViInt32 pulseType,
                                                    ViInt32 numberOfSamples,
                                                    ViReal64 sampleInterval,
                                                    ViBoolean state);
ViStatus _VI_FUNC rsngmo_configurePulseTrigger (ViSession instrumentHandle,
                                                ViInt32 channel, ViInt32 source,
                                                ViInt32 triggerRange,
                                                ViReal64 triggerLevel,
                                                ViInt32 triggerCount, ViInt32 slope,
                                                ViInt32 offset, ViReal64 timeout);
ViStatus _VI_FUNC rsngmo_setMeasurementFunction (ViSession instrumentHandle,
                                                 ViInt32 channel, ViInt32 function);
ViStatus _VI_FUNC rsngmo_getMeasurementFunction (ViSession instrumentHandle,
                                                 ViInt32 channel,
                                                 ViPInt32 function);
ViStatus _VI_FUNC rsngmo_setCurrentMeasurementRange (ViSession instrumentHandle,
                                                     ViInt32 channel,
                                                     ViInt32 range);
ViStatus _VI_FUNC rsngmo_getCurrentMeasurementRange (ViSession instrumentHandle,
                                                     ViInt32 channel,
                                                     ViPInt32 range);
ViStatus _VI_FUNC rsngmo_setMeasurementInterval (ViSession instrumentHandle,
                                                 ViInt32 channel,
                                                 ViReal64 interval);
ViStatus _VI_FUNC rsngmo_getMeasurementInterval (ViSession instrumentHandle,
                                                 ViInt32 channel,
                                                 ViPReal64 interval);
ViStatus _VI_FUNC rsngmo_setAverageCount (ViSession instrumentHandle,
                                          ViInt32 channel, ViInt32 averageCount);
ViStatus _VI_FUNC rsngmo_getAverageCount (ViSession instrumentHandle,
                                          ViInt32 channel, ViPInt32 averageCount);
ViStatus _VI_FUNC rsngmo_getPulseTriggerState (ViSession instrumentHandle,
                                               ViInt32 channel, ViPInt32 state);
ViStatus _VI_FUNC rsngmo_setPulseChannel (ViSession instrumentHandle,
                                          ViInt32 channel, ViInt32 pulseChannel);
ViStatus _VI_FUNC rsngmo_getPulseChannel (ViSession instrumentHandle,
                                          ViInt32 channel, ViPInt32 pulseChannel);
ViStatus _VI_FUNC rsngmo_setPulseState (ViSession instrumentHandle, ViInt32 channel,
                                        ViBoolean state);
ViStatus _VI_FUNC rsngmo_getPulseState (ViSession instrumentHandle, ViInt32 channel,
                                        ViPBoolean state);
ViStatus _VI_FUNC rsngmo_setPulseMeasurementType (ViSession instrumentHandle,
                                                  ViInt32 channel, ViInt32 type);
ViStatus _VI_FUNC rsngmo_getPulseMeasurementType (ViSession instrumentHandle,
                                                  ViInt32 channel, ViPInt32 type);
ViStatus _VI_FUNC rsngmo_setPulseTriggerLevel (ViSession instrumentHandle,
                                               ViInt32 channel,
                                               ViInt32 triggerRange,
                                               ViReal64 triggerLevel);
ViStatus _VI_FUNC rsngmo_getPulseTriggerLevel (ViSession instrumentHandle,
                                               ViInt32 channel,
                                               ViInt32 triggerRange,
                                               ViPReal64 triggerLevel);
ViStatus _VI_FUNC rsngmo_setPulseTriggerSource (ViSession instrumentHandle,
                                                ViInt32 channel, ViInt32 source);
ViStatus _VI_FUNC rsngmo_getPulseTriggerSource (ViSession instrumentHandle,
                                                ViInt32 channel, ViPInt32 source);
ViStatus _VI_FUNC rsngmo_setPulseTriggerSlope (ViSession instrumentHandle,
                                               ViInt32 channel, ViInt32 slope);
ViStatus _VI_FUNC rsngmo_getPulseTriggerSlope (ViSession instrumentHandle,
                                               ViInt32 channel, ViPInt32 slope);
ViStatus _VI_FUNC rsngmo_setPulseTriggerOffset (ViSession instrumentHandle,
                                                ViInt32 channel, ViInt32 offset);
ViStatus _VI_FUNC rsngmo_getPulseTriggerOffset (ViSession instrumentHandle,
                                                ViInt32 channel, ViPInt32 offset);
ViStatus _VI_FUNC rsngmo_setPulseTriggerCount (ViSession instrumentHandle,
                                               ViInt32 channel,
                                               ViInt32 triggerCount);
ViStatus _VI_FUNC rsngmo_getPulseTriggerCount (ViSession instrumentHandle,
                                               ViInt32 channel, ViPInt32 count);
ViStatus _VI_FUNC rsngmo_setPulseTriggerTimeout (ViSession instrumentHandle,
                                                 ViInt32 channel, ViReal64 timeout);
ViStatus _VI_FUNC rsngmo_getPulseTriggerTimeout (ViSession instrumentHandle,
                                                 ViInt32 channel,
                                                 ViPReal64 timeout);
ViStatus _VI_FUNC rsngmo_setPulseNumberOfSamples (ViSession instrumentHandle,
                                                  ViInt32 channel,
                                                  ViInt32 numberOfSamples);
ViStatus _VI_FUNC rsngmo_getPulseNumberOfSamples (ViSession instrumentHandle,
                                                  ViInt32 channel,
                                                  ViPInt32 numberOfSamples);
ViStatus _VI_FUNC rsngmo_setPulseSampleInterval (ViSession instrumentHandle,
                                                 ViInt32 channel,
                                                 ViReal64 sampleInterval);
ViStatus _VI_FUNC rsngmo_getPulseSampleInterval (ViSession instrumentHandle,
                                                 ViInt32 channel,
                                                 ViPReal64 sampleInterval);
ViStatus _VI_FUNC rsngmo_fetchMeasurement (ViSession instrumentHandle,
                                           ViInt32 channel, ViPReal64 value);
ViStatus _VI_FUNC rsngmo_fetchMeasurementArray (ViSession instrumentHandle,
                                                ViInt32 channel, ViInt32 arraySize,
                                                ViReal64 _VI_FAR data[],
                                                ViPInt32 actualNumberOfSamples);
ViStatus _VI_FUNC rsngmo_readMeasurement (ViSession instrumentHandle,
                                          ViInt32 channel, ViPReal64 value);
ViStatus _VI_FUNC rsngmo_readMeasurementArray (ViSession instrumentHandle,
                                               ViInt32 channel, ViInt32 arraySize,
                                               ViReal64 _VI_FAR data[],
                                               ViPInt32 actualNumberOfSamples);
ViStatus _VI_FUNC rsngmo_measure (ViSession instrumentHandle, ViInt32 channel,
                                  ViInt32 function, ViPReal64 value);
ViStatus _VI_FUNC rsngmo_setStatusRegister (ViSession instrumentHandle,
                                            ViInt32 register, ViInt32 value);
ViStatus _VI_FUNC rsngmo_getStatusRegister (ViSession instrumentHandle,
                                            ViInt32 register, ViPInt32 value);
ViStatus _VI_FUNC rsngmo_presetStatusRegisters (ViSession instrumentHandle);
ViStatus _VI_FUNC rsngmo_clearAllRegisters (ViSession instrumentHandle);
ViStatus _VI_FUNC rsngmo_writeToInstr (ViSession instrumentHandle,
                                       ViChar _VI_FAR writeBuffer[]);
ViStatus _VI_FUNC rsngmo_readInstrData (ViSession instrumentHandle,
                                        ViInt32 numberBytesToRead,
                                        ViChar _VI_FAR readBuffer[],
                                        ViPInt32 numBytesRead);
ViStatus _VI_FUNC rsngmo_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC rsngmo_self_test (ViSession instrumentHandle,
                                    ViPInt32 selfTestResult);
ViStatus _VI_FUNC rsngmo_error_query (ViSession instrumentHandle,
                                      ViPInt32 errorCode,
                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rsngmo_ClearErrorQueue (ViSession instrumentHandle);
ViStatus _VI_FUNC rsngmo_error_message (ViSession instrumentHandle,
                                        ViStatus statusCode,
                                        ViChar _VI_FAR message[]);
ViStatus _VI_FUNC rsngmo_revision_query (ViSession instrumentHandle,
                                         ViChar _VI_FAR instrumentDriverRevision[],
                                         ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rsngmo_saveSetup (ViSession instrumentHandle, ViInt32 userSetup);
ViStatus _VI_FUNC rsngmo_recallSetup (ViSession instrumentHandle,
                                      ViInt32 setupNumber);
ViStatus _VI_FUNC rsngmo_setCheckStatus (ViSession instrumentHandle,
                                         ViBoolean state);
ViStatus _VI_FUNC rsngmo_getCheckStatus (ViSession instrumentHandle,
                                         ViPBoolean state);
ViStatus _VI_FUNC rsngmo_close (ViSession instrumentHandle);

/*****************************************************************************/
/*= INSTRUMENT-DEPENDENT FUNCTION DECLARATIONS ==============================*/
/*****************************************************************************/

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
